# Traceability Tree

Total nodes: 8

- ▶REQ-p00001: User Authentication [Active]
  - ▶REQ-o00001: Production Deployment [Active]
    - REQ-d00001: Authentication Module [Active]
  - REQ-d00001: Authentication Module [Active]
  - ▶REQ-p00003: Audit Logging [Active]
    - REQ-d00003: Audit Trail Implementation [Active]
- ▶REQ-p00002: Data Privacy [Active]
  - ▶REQ-o00001: Production Deployment [Active]
    - REQ-d00001: Authentication Module [Active]
  - ▶REQ-o00002: Backup Strategy [Active]
    - REQ-d00002: Privacy Controls [Active]
  - REQ-d00002: Privacy Controls [Active]
  - ▶REQ-p00003: Audit Logging [Active]
    - REQ-d00003: Audit Trail Implementation [Active]

## Statistics

Type | Count
--- | ---
Requirement | 8

Generated by elspais (tree mode)